write_profile

Function write_profile 

pub fn write_profile(
    path: &Path,
    profile_name: &str,
    account_id: &str,
    client_id: &str,
    client_secret: &str,
) -> Result<(), ApiError>
Write (or overwrite) a single profile in the config file, preserving other profiles and any comments or formatting in unmodified sections.

Creates the config directory and file if they don’t exist, then sets permissions to 0600 on unix.